<?php

/**
 * Ruki Media: Theme Boost Customizer Settings
 * This file was added in plugin version 1.1.0
 *
 * @package WordPress
 * @subpackage Ruki Media
 * @since 1.0
 * @version 1.1
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

// Register customizer settings

function ruki_theme_boost_customize_register( $wp_customize ) {

		// ========================================================
		// SEO
		// ========================================================

		$wp_customize->add_section( 'ruki_performance_seo_settings', array(
			'title'    => esc_html__( 'Ruki: SEO & Misc. Settings', 'ruki-theme-boost' ),
			'priority' => 160,
			'description' => esc_html__( 'Use these settings to improve your site performace', 'ruki-theme-boost' ),
		) );


		// Image quality
		$wp_customize->add_setting( 'ruki_image_quality', array(
			'default'           => '82',
			'sanitize_callback' => 'absint',
		) );

		$wp_customize->add_control( 'ruki_image_quality', array(
			'label'       => esc_html__( 'Image Quality (%)', 'ruki-theme-boost' ),
			'description' => esc_html__( 'Lower quality provides a smaller file size and faster loading pages. Remember to regenerate your thumbnails after changing this setting. WordPress default setting is "82"', 'ruki-theme-boost' ),
			'section'     => 'ruki_performance_seo_settings',
			'type'        => 'number',
			'input_attrs' => array(
			        'min'   => 0,
			        'max' => 100,
			        'step' => 1,
			    ),
		) );

		// Human entry date
		$wp_customize->add_setting( 'ruki_human_entry_date', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_human_entry_date', array(
			'label'       => esc_html__( 'Human Readable Entry Date', 'ruki-theme-boost' ),
			'section'     => 'ruki_performance_seo_settings',
			'type'        => 'checkbox',
		) );

		// Human entry date
		$wp_customize->add_setting( 'ruki_human_comment_date', array(
			'default'           => false,
			'sanitize_callback' => 'ruki_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'ruki_human_comment_date', array(
			'label'       => esc_html__( 'Human Readable Comment Date', 'ruki-theme-boost' ),
			'section'     => 'ruki_performance_seo_settings',
			'type'        => 'checkbox',
		) );

		// read time string
		$wp_customize->add_setting( 'ruki_read_time_string', array(
			'default'           => 'minute read',
			'sanitize_callback' => 'ruki_sanitize_text',
		) );

		$wp_customize->add_control( 'ruki_read_time_string', array(
			'label'       => esc_html__( 'Read Time Text String', 'ruki-theme-boost' ),
			'section'     => 'ruki_performance_seo_settings',
			'type'        => 'text',
		) );

}

add_action( 'customize_register', 'ruki_theme_boost_customize_register', 100 );


// ========================================================
// Sanitize Checkbox
// ========================================================
/**
* @param $input
* @return bool
*/

if ( ! function_exists( 'ruki_sanitize_checkbox' ) ) {

	function ruki_sanitize_checkbox( $input ) {

			return ( $input === true ) ? true : false;

	}

}

// ========================================================
// Sanitize Text
// ========================================================

if ( ! function_exists( 'ruki_sanitize_text' ) ) {

	function carrino_sanitize_text( $text ) {
	    return sanitize_text_field( $text );
	}

}


?>