<?php

/**
 * 340 Media: Theme Boost Functions
 *
 * @since 1.0
 * @version 1.4
 */

// ========================================================
// Calculate reading time for each post
// ========================================================

if ( ! function_exists( 'ruki_read_time' ) ) {

	function ruki_read_time() {
	    $post_content = get_post_field( 'post_content' );
	    $word_count = str_word_count( strip_tags( $post_content ) );
	    $readingtime = ceil( $word_count / 300);

	    $readtime = $readingtime . ' ' . get_theme_mod( 'ruki_read_time_string', 'minute read' );

	    return $readtime;
	}

}

// ========================================================
// Output the related category links in post meta
// ========================================================
/**
 * This function only exists to handle Many category EDGE case
 * We use it for archive (not single) loops
 */

if ( ! function_exists( 'ruki_get_category' ) ) {

	function ruki_get_category( $num = 2 ) {

		global $post;

		$category = get_the_category($post->id);

		$count = 0;

		$output =  '<ul class="post-categories">';

		foreach($category as $the_category) {

			$count++;

			$output .= '<li class="cat-slug-' . esc_attr( $the_category->slug ) . ' cat-id-' . esc_attr( $the_category->cat_ID ) . '"><a href="' . get_category_link( $the_category->cat_ID ) . '" class="cat-link-' . esc_attr( $the_category->cat_ID ) . '">' . esc_attr( $the_category->cat_name ) . '</a></li>';

			if ( $count === $num ) {

				break; // Simply break after the defined number of categories

			}

		}

		$output .= '</ul>';

		return $output;

	}

}

// ========================================================
// Generate human readable date
// ========================================================

if ( ! function_exists('ruki_human_entry_date') ) {

	function ruki_human_entry_date() {

		$the_post_date = get_the_date();

		if ( get_theme_mod( 'ruki_human_entry_date', false ) ) {

			$the_post_date =  human_time_diff( get_the_time('U'), current_time( 'timestamp' ) ) . ' ' . esc_html__('ago', 'ruki-theme-boost' );

		} 

		 return $the_post_date;

	}

}

// ========================================================
// Generate human readable updated date
// ========================================================

if ( ! function_exists('ruki_human_updated_date') ) {

	function ruki_human_updated_date() {

		$the_updated_date = get_the_modified_date();

		if ( get_theme_mod( 'ruki_human_entry_date', false ) ) {

			$the_updated_date =  human_time_diff( get_the_modified_time('U'), current_time( 'timestamp' ) ) . ' ' . esc_html__('ago', 'ruki-theme-boost' );

		} 

		 return $the_updated_date;

	}

}

// ========================================================
// Generate human readable comment date
// ========================================================

if ( ! function_exists('ruki_human_comment_date') && get_theme_mod( 'ruki_human_comment_date', false ) ) {

	function ruki_human_comment_date() {

			$the_comment_date =  human_time_diff( get_comment_time('U'), current_time( 'timestamp' ) ) . ' ' . esc_html__('ago', 'ruki-theme-boost' );

		 return $the_comment_date;

	}

	add_filter( 'get_comment_date', 'ruki_human_comment_date' );

}

// ========================================================
// Filter image compression/quality
// ========================================================
// Added in v1.1

function ruki_set_image_quality() {

	return get_theme_mod( 'ruki_image_quality', 82 );

}

add_filter( 'jpeg_quality', 'ruki_set_image_quality');

// ========================================================
// Add class to body tag
// ========================================================

function ruki_theme_boost_class( $classes ) {

	if ( function_exists('sb_instagram_feed_init') && get_theme_mod( 'ruki_sbi_theme_style', false ) ) {

		$classes[] = 'sbi-theme-style';
	}
	return $classes;
}
add_filter( 'body_class', 'ruki_theme_boost_class' );




?>