<?php

/**
 * 340 Media: Custom Meta Boxes
 *
 * @since 1.0
 * @version 1.1
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

define( 'RUKI_META_BOXES__PLUGIN_DIR', plugin_dir_path( __FILE__ ) );


// ========================================================
// Add single post meta box settings
// ========================================================

if ( ! function_exists( 'ruki_custom_meta_box' ) ) {

	function ruki_custom_meta_box() {

		add_meta_box(
			'ruki_single_options',
			esc_html__( 'Ruki Single Post Options', 'ruki-theme-boost' ),
			'ruki_meta_box_callback',
			'post',
			'side',
			'low'
			);

		add_meta_box(
			'ruki_page_options',
			esc_html__( 'Ruki Page Options', 'ruki-theme-boost' ),
			'ruki_page_meta_box_callback',
			'page',
			'side',
			'low'
			);

	}
}

add_action( 'add_meta_boxes', 'ruki_custom_meta_box' );

// ========================================================
// Post meta callback
// ========================================================

if ( ! function_exists( 'ruki_meta_box_callback' ) ) {

	function ruki_meta_box_callback( $post ) {

		wp_nonce_field(basename( __FILE__ ), 'ruki_post_meta_nonce' );

		// ========================================================
		// Select override global post style
		// ========================================================
		echo '<p><label for="ruki_single_post_style"><b>' . esc_html__( 'Post style', 'ruki-theme-boost' ) . '</b></label></p>';
		echo '<p><select name="ruki_single_post_style">';

		$values = array(
			'global' => 'Use Global Setting',
			'default' => 'Default',
			'default-alt' => 'Default Alt.',
			'cover' => 'Cover',
			'hero' => 'Hero',
		);

		foreach ($values as $key => $value ) {
			
			if ( $key == get_post_meta($post->ID, 'ruki_single_post_style', true ) ) {
				echo '<option selected value="' . esc_attr( $key ) . '">' . esc_html__( '' . $value, 'ruki-theme-boost' ) . '</option>';
			} else {
				echo '<option value="' . esc_attr( $key ) . '">' . esc_html__( '' . $value, 'ruki-theme-boost' ) . '</option>';
			}
		}

		echo '</select></p>';

		// ========================================================
		// Select override global sidebar setting (single)
		// ========================================================
		echo '<p><label for="ruki_single_post_sidebar"><b>' . esc_html__( 'Sidebar', 'ruki-theme-boost' ) . '</b></label></p>';
		echo '<p><select name="ruki_single_post_sidebar">';

		$values = array(
			'global' => 'Use Global Setting',
			'has-sidebar' => 'Enable Sidebar',
			'disabled-sidebar' => 'Disable Sidebar',
		);

		foreach ($values as $key => $value ) {
			
			if ( $key == get_post_meta($post->ID, 'ruki_single_post_sidebar', true ) ) {
				echo '<option selected value="' . esc_attr( $key ) . '">' . esc_html__( '' . $value, 'ruki-theme-boost' ) . '</option>';
			} else {
				echo '<option value="' . esc_attr( $key ) . '">' . esc_html__( '' . $value, 'ruki-theme-boost' ) . '</option>';
			}
		}

		echo '</select></p>';

		// ========================================================
		// Checkbox disable featured image or media (single)
		// ========================================================
		$value = get_post_meta( $post->ID, 'ruki_disable_featured_media', true );

		echo '<label for="ruki_disable_featured_media">';
		if ($value == '') {
			echo ' <input id="ruki_disable_featured_media" name="ruki_disable_featured_media" type="checkbox" class="checkbox">';
		} else {
			echo ' <input id="ruki_disable_featured_media" name="ruki_disable_featured_media" type="checkbox" class="checkbox" checked="checked">';
		}
		echo esc_html__( 'Disable Featured Image/Media', 'ruki-theme-boost' );
		echo '</label>';

	}

}

// ========================================================
// Page meta callback
// ========================================================

if ( ! function_exists( 'ruki_page_meta_box_callback' ) ) {

	function ruki_page_meta_box_callback( $post ) {

		wp_nonce_field(basename( __FILE__ ), 'ruki_post_meta_nonce' );

		// ========================================================
		// Select override global sidebar setting (page)
		// ========================================================
		echo '<p><label for="ruki_single_page_sidebar"><b>' . esc_html__( 'Sidebar', 'ruki-theme-boost' ) . '</b></label></p>';
		echo '<p><select name="ruki_single_page_sidebar">';

		$values = array(
			'global' => 'Use Global Setting',
			'has-sidebar' => 'Enable Sidebar',
			'disabled-sidebar' => 'Disable Sidebar',
		);

		foreach ($values as $key => $value ) {
			
			if ( $key == get_post_meta($post->ID, 'ruki_single_page_sidebar', true ) ) {
				echo '<option selected value="' . esc_attr( $key ) . '">' . esc_html__( '' . $value, 'ruki-theme-boost' ) . '</option>';
			} else {
				echo '<option value="' . esc_attr( $key ) . '">' . esc_html__( '' . $value, 'ruki-theme-boost' ) . '</option>';
			}
		}

		echo '</select></p>';

	}

}

if ( ! function_exists( 'ruki_save_meta_post_data' ) ) {

	function ruki_save_meta_post_data( $post_id ) {

		// Return if meta-box doesnt exist
		if ( ! isset( $_POST['ruki_post_meta_nonce'] ) ) {
			return;
		}
		// Return if nonce is not valid
		if ( ! wp_verify_nonce( $_POST['ruki_post_meta_nonce'], basename( __FILE__ ))) {
			return;
		}
		// Return if doing and autosave
		if ( defined( 'DOING_AUTOAVE' ) && DOING_AUTOSAVE ) {
			return;
		}

		// Return if user does not have permisson
		if ( ! current_user_can( 'edit_post', $post_id )) {
			return;
		}

		// Featured media checkbox

		$featured_media_checkbox = false;

		if (isset($_POST['ruki_disable_featured_media']))
	    {
	        $featured_media_checkbox = true;
	    } 

		update_post_meta( $post_id, 'ruki_disable_featured_media', $featured_media_checkbox );

		// Post style 

		$single_post_style = '';

		if (isset($_POST['ruki_single_post_style']))
	    {
	        $single_post_style = $_POST['ruki_single_post_style'];
	    } 

		update_post_meta( $post_id, 'ruki_single_post_style', $single_post_style );

		// Post sidebar

		$single_post_sidebar = '';

		if (isset($_POST['ruki_single_post_sidebar']))
	    {
	        $single_post_sidebar = $_POST['ruki_single_post_sidebar'];
	    } 

		update_post_meta( $post_id, 'ruki_single_post_sidebar', $single_post_sidebar );

		// Page sidebar

		$single_page_sidebar = '';

		if (isset($_POST['ruki_single_page_sidebar']))
	    {
	        $single_page_sidebar = $_POST['ruki_single_page_sidebar'];
	    } 

		update_post_meta( $post_id, 'ruki_single_page_sidebar', $single_page_sidebar );
	}
}

add_action( 'save_post', 'ruki_save_meta_post_data' );


?>